@@ -45,65 +45,36 @@ use Text::Wrap::Smart ':all';
 # UTF-8 is required for special character handling
 binmode(STDERR, ":encoding(UTF-8)");
 binmode(STDOUT, ":encoding(UTF-8)");
-binmode(STDIN, ":encoding(UTF-8)");
+binmode(STDIN,  ":encoding(UTF-8)");
 
 BEGIN {
-    our $VERSION = '1.26';
+    our $VERSION = '1.27';
 }
 
 sub ansi_output {
     my $self  = shift;
     my $text  = shift;
-    my $delay = shift || 0;
-    my $test  = shift || FALSE;
 
-    while ($text =~ /\[\% .*? \%\]/) {
-        if (length($text) > 1) {
+	if (length($text) > 1) {
+		while ($text =~ /\[\% (.*?) \%\]/) {
+			warn $1;
             while ($text =~ /\[\%\s+BOX (.*?),(\d+),(\d+),(\d+),(\d+),(.*?)\s+\%\](.*?)\[\%\s+ENDBOX\s+\%\]/i) {
                 my $replace = $self->box($1, $2, $3, $4, $5, $6, $7);
                 $text =~ s/\[\%\s+BOX.*?\%\].*?\[\%\s+ENDBOX.*?\%\]/$replace/i;
             }
             foreach my $string (keys %{ $self->{'ansi_sequences'} }) {
-
-                #				if ($string =~ /CLEAR|CLS/i) {
-                #					my $ch = locate(1, 1) . cls;
-                #					$text =~ s/\[\%\s+$string\s+\%\]/$ch/gi;
-                #				} else {
                 $text =~ s/\[\%\s+$string\s+\%\]/$self->{'ansi_sequences'}->{$string}/gi;
-
-                #				}
-            } ## end foreach my $string (keys %{...})
+            }
             foreach my $string (keys %{ $self->{'characters'}->{'NAME'} }) {
                 $text =~ s/\[\%\s+$string\s+\%\]/$self->{'characters'}->{'NAME'}->{$string}/gi;
             }
             foreach my $string (keys %{ $self->{'characters'}->{'UNICODE'} }) {
                 $text =~ s/\[\%\s+$string\s+\%\]/$self->{'characters'}->{'UNICODE'}->{$string}/gi;
             }
-        } ## end if (length($text) > 1)
-    } ## end while ($text =~ /\[\% .*? \%\]/)
-    my $s_len = length($text);
-    my $nl    = $self->{'ansi_sequences'}->{'NEWLINE'};
-    my $found = FALSE;
-    if ($test) {
-        $text =~ s/\n/$nl/gs;
-        return ($text);
-    } else {
-        foreach my $count (0 .. $s_len) {
-            my $char = substr($text, $count, 1);
-            if ($char eq "\n") {
-                if ($text !~ /$nl/) {    # translate only if the file doesn't have ASCII newlines
-                    $char = $nl;
-                }
-            } elsif ($char eq chr(27)) {    # Don't slow down ANSI sequences
-                $found = TRUE;
-            } elsif ($char eq 'm') {
-                $found = FALSE;
-            } elsif (!$found) {
-                sleep $delay if ($delay);
-            }
-            print $char;
-        } ## end foreach my $count (0 .. $s_len)
-    } ## end else [ if ($test) ]
+        }
+		$text =~ s/\[ \% TOKEN \% \]/\[\% TOKEN \%\]/;
+		print $text;
+    }
     return (TRUE);
 } ## end sub ansi_output
 
@@ -177,11 +148,12 @@ sub new {
             'LINEFEED' => chr(10),
             'NEWLINE'  => chr(13) . chr(10),
 
-            'CLEAR'      => $esc . '2J',
-            'CLS'        => $esc . '2J',
+            'CLEAR'      => $esc . '2J' . $esc . 'H',
+            'CLS'        => $esc . '2J' . $esc . 'H',
             'CLEAR LINE' => $esc . '0K',
             'CLEAR DOWN' => $esc . '0J',
             'CLEAR UP'   => $esc . '1J',
+            'HOME'       => $esc . 'H',
 
             # Cursor
             'UP'      => $esc . 'A',
@@ -261,22 +233,23 @@ sub new {
             'BRIGHT B_CYAN'    => $esc . '106m',
             'BRIGHT B_WHITE'   => $esc . '107m',
 
-            'HORIZONTAL RULE ORANGE'         => '[% RETURN %]' . $esc . '48;5;202m' . clline . $esc . '0m',
-            'HORIZONTAL RULE PINK'           => '[% RETURN %]' . $esc . '48;5;198m' . clline . $esc . '0m',
-            'HORIZONTAL RULE RED'            => '[% RETURN %]' . $esc . '41m' . clline . $esc . '0m',
-            'HORIZONTAL RULE BRIGHT RED'     => '[% RETURN %]' . $esc . '101m' . clline . $esc . '0m',
-            'HORIZONTAL RULE GREEN'          => '[% RETURN %]' . $esc . '42m' . clline . $esc . '0m',
-            'HORIZONTAL RULE BRIGHT GREEN'   => '[% RETURN %]' . $esc . '102m' . clline . $esc . '0m',
-            'HORIZONTAL RULE YELLOW'         => '[% RETURN %]' . $esc . '43m' . clline . $esc . '0m',
-            'HORIZONTAL RULE BRIGHT YELLOW'  => '[% RETURN %]' . $esc . '103m' . clline . $esc . '0m',
-            'HORIZONTAL RULE BLUE'           => '[% RETURN %]' . $esc . '44m' . clline . $esc . '0m',
-            'HORIZONTAL RULE BRIGHT BLUE'    => '[% RETURN %]' . $esc . '104m' . clline . $esc . '0m',
-            'HORIZONTAL RULE MAGENTA'        => '[% RETURN %]' . $esc . '45m' . clline . $esc . '0m',
-            'HORIZONTAL RULE BRIGHT MAGENTA' => '[% RETURN %]' . $esc . '105m' . clline . $esc . '0m',
-            'HORIZONTAL RULE CYAN'           => '[% RETURN %]' . $esc . '46m' . clline . $esc . '0m',
-            'HORIZONTAL RULE BRIGHT CYAN'    => '[% RETURN %]' . $esc . '106m' . clline . $esc . '0m',
-            'HORIZONTAL RULE WHITE'          => '[% RETURN %]' . $esc . '47m' . clline . $esc . '0m',
-            'HORIZONTAL RULE BRIGHT WHITE'   => '[% RETURN %]' . $esc . '107m' . clline . $esc . '0m',
+			# MACROS
+            'HORIZONTAL RULE ORANGE'         => '[% RETURN %][% B_ORANGE %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE PINK'           => '[% RETURN %][% B_PINK %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE RED'            => '[% RETURN %][% B_RED %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE BRIGHT RED'     => '[% RETURN %][% BRIGHT B_RED %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE GREEN'          => '[% RETURN %][% B_GREEN %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE BRIGHT GREEN'   => '[% RETURN %][% BRIGHT B_GREEN %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE YELLOW'         => '[% RETURN %][% B_YELLOW %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE BRIGHT YELLOW'  => '[% RETURN %][% BRIGHT B_YELLOW %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE BLUE'           => '[% RETURN %][% B_BLUE %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE BRIGHT BLUE'    => '[% RETURN %][% BRIGHT B_BLUE %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE MAGENTA'        => '[% RETURN %][% B_MAGENTA %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE BRIGHT MAGENTA' => '[% RETURN %][% BRIGHT B_MAGENTA %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE CYAN'           => '[% RETURN %][% B_CYAN %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE BRIGHT CYAN'    => '[% RETURN %][% BRIGHT B_CYAN %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE WHITE'          => '[% RETURN %][% B_WHITE %][% CLEAR LINE %][% RESET %]',
+            'HORIZONTAL RULE BRIGHT WHITE'   => '[% RETURN %][% BRIGHT B_WHITE %][% CLEAR LINE %][% RESET %]',
         },
         @_,
     };
@@ -358,7 +331,21 @@ Richard Kelsch
 
  Copyright (C) 2025 Richard Kelsch
  All Rights Reserved
- GNU Public License 3.0
+ Perl Artistic License
+
+This program is free software; you can redistribute it and/or modify it under the terms of the the Artistic License (2.0). You may obtain a copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified Versions is governed by this Artistic License. By using, modifying or distributing the Package, you accept this license. Do not use, modify, or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made by someone other than you, you are nevertheless required to ensure that your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge patent license to make, have made, use, offer to sell, sell, import and otherwise transfer the Package with respect to any patent claims licensable by the Copyright Holder that are necessarily infringed by the Package. If you institute patent litigation (including a cross-claim or counterclaim) against any party alleging that the Package constitutes direct or contributory patent infringement, then this Artistic License to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 USAGE
 
